@@ -27,6 +27,7 @@
 #include "audio.h"
 #include "solid_gl.h"
 #include "config.h"
+#include "video.h"
 
 #include "game_client.h"
 #include "game_common.h"
@@ -36,6 +37,10 @@
 
 /*---------------------------------------------------------------------------*/
 
+int game_compat_map;                    /* Client/server map compat flag     */
+
+/*---------------------------------------------------------------------------*/
+
 static int client_state = 0;
 
 static struct s_file file;
@@ -72,6 +77,11 @@ static int ups;                         /* Updates per second                */
 static int first_update;                /* First update flag                 */
 static int curr_ball;                   /* Current ball index                */
 
+struct
+{
+    int x, y;
+} version;                              /* Current map version               */
+
 /*---------------------------------------------------------------------------*/
 
 static void game_run_cmd(const union cmd *cmd)
@@ -346,6 +356,18 @@ static void game_run_cmd(const union cmd *cmd)
             }
             break;
 
+        case CMD_MAP:
+
+            /*
+             * Note if the loaded map matches the server's
+             * expectations. (No, this doesn't actually load a map,
+             * yet.  Something else somewhere else does.)
+             */
+
+            free(cmd->map.name);
+            game_compat_map = version.x == cmd->map.version.x;
+            break;
+
         case CMD_NONE:
         case CMD_MAX:
             break;
@@ -361,7 +383,7 @@ void game_client_step(FILE *demo_fp)
     {
         /*
          * Note: cmd_put is called first here because game_run_cmd
-         * frees the filename of CMD_SOUND.
+         * frees some command struct members.
          */
 
         if (demo_fp)
@@ -411,6 +433,10 @@ int  game_client_init(const char *file_name)
     fade_k =  1.0f;
     fade_d = -2.0f;
 
+
+    version.x = 0;
+    version.y = 0;
+
     for (i = 0; i < file.dc; i++)
     {
         char *k = file.av + file.dv[i].ai;
@@ -418,8 +444,20 @@ int  game_client_init(const char *file_name)
 
         if (strcmp(k, "back") == 0) back_name = v;
         if (strcmp(k, "grad") == 0) grad_name = v;
+
+        if (strcmp(k, "version") == 0)
+            sscanf(v, "%d.%d", &version.x, &version.y);
     }
 
+    /*
+     * If the client map's version is 1, assume the map is compatible
+     * with the server.  This ensures that 1.5.0 replays don't trigger
+     * bogus map compatibility warnings.  (Post-1.5.0 replays will
+     * have CMD_MAP override this.)
+     */
+
+    game_compat_map = version.x == 1;
+
     part_reset(GOAL_HEIGHT, JUMP_HEIGHT);
 
     view_fov = (float) config_get_d(CONFIG_VIEW_FOV);
@@ -883,7 +921,7 @@ void game_draw(int pose, float t)
 
     if (client_state)
     {
-        config_push_persp(fov, 0.1f, FAR_DIST);
+        video_push_persp(fov, 0.1f, FAR_DIST);
         glPushMatrix();
         {
             float T[16], U[16], M[16], v[3];
@@ -950,7 +988,7 @@ void game_draw(int pose, float t)
             game_draw_fore(pose, T, +1, t);
         }
         glPopMatrix();
-        config_pop_matrix();
+        video_pop_matrix();
 
         /* Draw the fade overlay. */
 
