@@ -3,9 +3,9 @@
 
 /*---------------------------------------------------------------------------*/
 
-#define STR_VIEW0 "Chase"
-#define STR_VIEW1 "Lazy"
-#define STR_VIEW2 "Manual"
+#define STR_VIEW0 _("Chase")
+#define STR_VIEW1 _("Lazy")
+#define STR_VIEW2 _("Manual")
 
 /*---------------------------------------------------------------------------*/
 
@@ -14,11 +14,8 @@ void hud_free(void);
 
 void hud_paint(void);
 void hud_timer(float);
+void hud_update(int);
 
-void hud_ball_pulse(float);
-void hud_time_pulse(float);
-void hud_coin_pulse(float);
-void hud_goal_pulse(float);
 void hud_view_pulse(int);
 
 /*---------------------------------------------------------------------------*/
