@@ -24,6 +24,7 @@
 #include "solid.h"
 #include "image.h"
 #include "config.h"
+#include "video.h"
 
 #define PI 3.1415926535897932
 
@@ -356,7 +357,7 @@ void fade_draw(float k)
         int w = config_get_d(CONFIG_WIDTH);
         int h = config_get_d(CONFIG_HEIGHT);
 
-        config_push_ortho();
+        video_push_ortho();
         {
             glEnable(GL_COLOR_MATERIAL);
             glDisable(GL_LIGHTING);
@@ -381,7 +382,7 @@ void fade_draw(float k)
             glEnable(GL_LIGHTING);
             glDisable(GL_COLOR_MATERIAL);
         }
-        config_pop_matrix();
+        video_pop_matrix();
     }
 }
 
